@@ -1,5 +1,7 @@
 
 import fastapi
+from fastapi.middleware.cors import CORSMiddleware
+
 import uvicorn
 from contextlib import asynccontextmanager
 
@@ -24,6 +26,13 @@ async def lifespan(app: fastapi.FastAPI):
 app = fastapi.FastAPI(lifespan=lifespan)
 app.include_router(chat_router)
 app.include_router(storage_router)
+app.add_middleware(
+    CORSMiddleware,
+    allow_origins=["*"],
+    allow_credentials=True,
+    allow_methods=["*"],
+    allow_headers=["*"]
+)
 
 
 def start_app():
