@@ -37,4 +37,4 @@ def add_middleware(tool: str, template: str):
     with open(init_file, "a") as f:
         f.write(f"from .{tool.lower()} import {tool.capitalize()}Tool\n")
 
-    print(f"Added {tool.capitalize()}Tool in {new_tool_path}")
+    return print(f"Added {tool.capitalize()}Tool in {new_tool_path}")
