@@ -21,9 +21,11 @@ class Config(metaclass=SingletonMeta):
         self.is_nocode = False
 
         if os.path.isfile("agent.json"):
-            self.agent_data = json.load(open("agent.json", "r"))
-            self.tools_data = self.agent_data.pop("tools")
-            self.secrets_data = self.agent_data.pop("secrets")
+            data = json.load(open("agent.json", "r"))
+
+            self.agent_data = data["agent"]
+            self.tools_data = data["tools"]
+            self.secrets_data = data["secrets"]
             self.is_nocode = True
 
         self.project_name = config["project"]["name"]
