@@ -9,15 +9,16 @@ from loguru import logger
 
 from .event import ToolEvent
 
-from AgentService.types import (
+from .types import (
     AgentResponse, Tool,
-    ToolAnswer, ChatToolState
+    ToolAnswer, ChatToolState,
+    Message
 )
 
-from AgentService.enums.tool import ToolResponse
-from AgentService.enums.agent import AgentResponseType
+from ..enums.tool import ToolResponse
+from ..enums.agent import AgentResponseType
 
-from AgentService.app.routes.chat.models import SendMessageRequest
+from AgentService.app.routes.chat.models import SendMessageRequest, GetChatRequest
 
 
 class AgentConnector:
@@ -156,13 +157,13 @@ class AgentConnector:
 
         return tool_answers
 
-    async def request(self, request: SendMessageRequest) -> AgentResponse:
-        self.log.debug(f"Sending request -> {request.to_dict()}")
+    async def request_post(self, request: SendMessageRequest) -> AgentResponse:
+        self.log.debug(f"Sending request -> {request.model_dump()}")
 
         async with aiohttp.ClientSession() as session:
             async with session.post(
                 url=f"{self.endpoint}/chat",
-                json=request.to_dict(),
+                json=request.model_dump(),
                 raise_for_status=False
             ) as resp:
 
@@ -173,8 +174,31 @@ class AgentConnector:
 
                 return agent_response
 
-    async def send(self, chat_id: str, text: str = None, context: dict = {}, tool_answers: list[ToolAnswer] = []) -> AgentResponse:
-        agent_response = await self.request(SendMessageRequest(chat_id=chat_id, text=text, context=context, tool_answers=tool_answers))
+    async def request_get(self, request: GetChatRequest) -> AgentResponse:
+        self.log.debug(f"Sending request -> {request.model_dump()}")
+
+        async with aiohttp.ClientSession() as session:
+            async with session.get(
+                url=f"{self.endpoint}/chat",
+                params=request.model_dump(),
+                raise_for_status=False
+            ) as resp:
+
+                self.log.debug(f"Got response -> {await resp.text()}")
+
+                response = await resp.json()
+                agent_response = AgentResponse(
+                    type=AgentResponseType.chat,
+                    content=response["data"]
+                )
+
+                return agent_response
+
+    async def send(self, chat_id: str, text: str = None, context: dict = {}, tool_answers: list[ToolAnswer] = [], is_manual: bool = False) -> AgentResponse:
+        agent_response = await self.request_post(SendMessageRequest(chat_id=chat_id, text=text, context=context, tool_answers=tool_answers))
+
+        if is_manual:
+            return agent_response
 
         if agent_response.type == AgentResponseType.answer:
             return agent_response
@@ -183,6 +207,9 @@ class AgentConnector:
 
         return await self.send(chat_id, tool_answers=tool_answers)
 
+    async def get_chat(self, chat_id: str) -> list[Message]:
+        return await self.request_get(GetChatRequest(chat_id=chat_id))
+
     async def send_tool_states(self, tools: list[Tool], chat_id: str):
         tool_answers = await self.handle_tools(tools, chat_id)
 
