@@ -2,7 +2,7 @@
 import io
 import json
 
-from beanie import Document
+from . import Document
 from beanie.odm.documents import PydanticObjectId
 from pydantic import model_validator
 
